@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Make authenticate requests to the API."""
 
@@ -40,7 +31,7 @@ from ...core.exceptions import log_exception
 from ...core import typing, ansi
 
 # public interface
-__all__ = ['WebApp', ]
+__all__ = ['APIClientApp', ]
 
 
 PROGRAM = 'refitt api'
@@ -87,7 +78,7 @@ options:
 log = logging.getLogger('refitt')
 
 
-class WebApp(Application):
+class APIClientApp(Application):
     """Application class for requests module."""
 
     interface = Interface(PROGRAM, USAGE, HELP)
@@ -198,7 +189,7 @@ class WebApp(Application):
 
     def make_request(self) -> dict:
         """Issue web request."""
-        return self.endpoint(extract_response=False, raise_on_error=False,
+        return self.endpoint(extract_response=False, raise_on_error=True,
                              **self.payload, **self.structured_options)
 
     @property
@@ -215,43 +206,9 @@ class WebApp(Application):
         if sys.stdout.isatty() and self.show_headers:
             self.format_headers(status, headers)
         if headers['Content-Type'] == 'application/octet-stream':
-            if not self.download:
-                if sys.stdout.isatty():
-                    print('---')
-                    print(f'{ansi.red("Content-Disabled")}: use --download to save file')
-                else:
-                    (filename, data), = content.items()
-                    sys.stdout.buffer.write(data)
-            else:
-                (filename, data), = content.items()
-                self.save_local(filename, data)
+            self.format_octet_stream(content)
         else:
-            if self.extraction_path is not None:
-                content = self.extract_partial(content, self.extraction_path)
-            if isinstance(content, (dict, list)):
-                content = json.dumps(content, indent=4)
-                if sys.stdout.isatty():
-                    Console().print(Syntax(content, 'json',
-                                           word_wrap=True, theme='solarized-dark',
-                                           background_color='default'))
-                else:
-                    print(content)
-            else:
-                content = json.dumps(content, indent=4)  # formats special types
-                if self.display_raw:
-                    content = content.strip('"')
-                print(content)
-
-    @staticmethod
-    def extract_partial(content: dict, path: str) -> Any:
-        """Pull sections or values out of nested `content`."""
-        result = dict(content)
-        for section in path.strip('.').split('.'):
-            try:
-                result = result[section]
-            except KeyError as error:
-                raise RuntimeError(f'Element not found \'{path}\'') from error
-        return result
+            self.format_json(content)
 
     @staticmethod
     def format_headers(status: int, headers: dict) -> None:
@@ -264,6 +221,48 @@ class WebApp(Application):
         for field, value in headers.items():
             print(f'{ansi.cyan(field)}: {value}')
 
+    def format_octet_stream(self, content: dict) -> None:
+        """Format output and save file to local disk if needed."""
+        if not self.download:
+            if sys.stdout.isatty():
+                print('---')
+                print(f'{ansi.red("Content-Disabled")}: use --download to save file')
+            else:
+                (filename, data), = content.items()
+                sys.stdout.buffer.write(data)
+        else:
+            (filename, data), = content.items()
+            self.save_local(filename, data)
+
+    def format_json(self, content: dict) -> None:
+        """Format output for JSON content."""
+        if self.extraction_path is not None:
+            content = self.extract_partial(content, self.extraction_path)
+        if isinstance(content, (dict, list)):
+            content = json.dumps(content, indent=4)
+            if sys.stdout.isatty():
+                Console().print(Syntax(content, 'json',
+                                       word_wrap=True, theme='solarized-dark',
+                                       background_color='default'))
+            else:
+                print(content)
+        else:
+            content = json.dumps(content, indent=4)  # formats special types
+            if self.display_raw:
+                content = content.strip('"')
+            print(content)
+
+    @staticmethod
+    def extract_partial(content: dict, path: str) -> Any:
+        """Pull sections or values out of nested `content`."""
+        result = dict(content)
+        for section in path.strip('.').split('.'):
+            try:
+                result = result[section]
+            except KeyError as error:
+                raise RuntimeError(f'Element not found \'{path}\'') from error
+        return result
+
     @staticmethod
     def save_local(filename: str, data: bytes) -> None:
         """Attempt to save `data` as local file to `filename` path."""
