@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Query database for records or statistics."""
 
@@ -191,7 +182,7 @@ class QueryDatabaseApp(Application):
             data = results
         if sys.stdout.isatty():
             Console().print(Syntax(json.dumps(data, indent=4), 'json',
-                                   word_wrap=True, theme='monokai',
+                                   word_wrap=True, theme='solarized-dark',
                                    background_color='default'))
         else:
             print(json.dumps(data, indent=4), file=sys.stdout, flush=True)
