@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Common exceptions and error handling."""
 
@@ -28,6 +19,9 @@ from cmdkit.app import exit_status
 # internal libs
 from .config import get_site
 
+# public interface
+__all__ = ['log_exception', 'handle_exception', ]
+
 
 def log_exception(exc: Exception, logger: Callable[[str], None], status: int) -> int:
     """Log the exception and exit with `status`."""
