@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Implements the common `Alert` interface for all broker clients."""
 
@@ -25,6 +16,9 @@ from abc import ABC, abstractmethod
 from ...database.model import ObjectType, Object, Source, ObservationType, Observation, Alert
 from ...database.core import Session
 
+# public interface
+__all__ = ['AlertInterface', ]
+
 
 # JSON-dict
 AlertJSON = Dict[str, Any]
