@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Core interface for database engine and session manager."""
 
@@ -29,6 +20,9 @@ from sqlalchemy.exc import ArgumentError
 # internal libs
 from ..core.config import config, Namespace, ConfigurationError
 
+# public interface
+__all__ = ['DatabaseURL', 'backends', 'engine', 'Session', 'config', ]
+
 
 # initialize module level logger
 log = logging.getLogger(__name__)
