@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Observation endpoints."""
 
@@ -31,6 +22,9 @@ from ..response import endpoint, PermissionDenied, PayloadTooLarge
 from ..auth import authenticated, authorization
 from ..tools import collect_parameters, disallow_parameters
 
+# public interface
+__all__ = []
+
 
 info: dict = {
     'Description': 'Request observations',
@@ -48,13 +42,14 @@ info: dict = {
         '/observation/<id>/forecast': {},
         '/observation/<id>/file': {},
         '/observation/<id>/file/type': {},
+        '/observation/type': {},
         '/observation/type/<id>': {},
         '/observation/alert/<id>': {},
         '/observation/forecast/<id>': {},
         '/observation/file/<id>': {},
         '/observation/file/<id>/type': {},
-        '/observation/file/type/<id>': {},
         '/observation/file/type': {},
+        '/observation/file/type/<id>': {},
     }
 }
 
@@ -659,6 +654,36 @@ info['Endpoints']['/observation/type/<id>']['GET'] = {
 }
 
 
+@application.route('/observation/type', methods=['GET'])
+@endpoint('application/json')
+@authenticated
+@authorization(level=None)
+def get_observation_types(client: Client) -> dict:  # noqa: unused client
+    """Query for list of all observation types."""
+    disallow_parameters(request)
+    return {'observation_type': [record.to_json() for record in ObservationType.query().all()]}
+
+
+info['Endpoints']['/observation/type']['GET'] = {
+    'Description': 'Request list of all observation types',
+    'Permissions': 'Public',
+    'Requires': {
+        'Auth': 'Authorization Bearer Token',
+    },
+    'Responses': {
+        200: {
+            'Description': 'Success',
+            'Payload': {
+                'Description': 'Observation type data',
+                'Type': 'application/json'
+            },
+        },
+        401: {'Description': 'Access revoked, token expired'},
+        403: {'Description': 'Token not found or invalid'},
+    }
+}
+
+
 @application.route('/observation/alert/<int:id>', methods=['GET'])
 @endpoint('application/json')
 @authenticated
