@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Cryptographic data and JSON Web Tokens (JWT)."""
 
@@ -33,6 +24,10 @@ from cryptography.fernet import Fernet, InvalidToken
 # internal libs
 from ..core.config import config, ConfigurationError
 
+# public interface
+__all__ = ['AuthError', 'TokenNotFound', 'TokenInvalid', 'TokenExpired', 'Cipher',
+           'CryptoDigits', 'RootKey', 'Key', 'Secret', 'Token', 'JWT', ]
+
 
 # initialize module level logger
 log = logging.getLogger(__name__)
@@ -72,10 +67,10 @@ class Cipher:
             api_config = config['api']
         except KeyError:
             raise ConfigurationError('Missing "api" section')
-        root_key = api_config.root_key
-        if root_key is None:
-            raise ConfigurationError('No "api.root_key" found')
-        return cls(root_key.encode())
+        rootkey = api_config.rootkey
+        if rootkey is None:
+            raise ConfigurationError('No "api.rootkey" found')
+        return cls(rootkey.encode())
 
     def encrypt(self, data: bytes) -> bytes:
         """Encrypt `data` with the Cipher."""
@@ -85,6 +80,11 @@ class Cipher:
         """Decrypt `data` with the Cipher."""
         return self._fernet.decrypt(data)
 
+    @classmethod
+    def new_rootkey(cls) -> RootKey:
+        """Generate a new cryptography 'rootkey' for deployments."""
+        return RootKey(Fernet.generate_key().decode())
+
 
 class CryptoDigits:
     """Generate and represent sensitive cryptographic strings."""
@@ -213,6 +213,11 @@ class CryptoDigits:
         return not self == other
 
 
+class RootKey(CryptoDigits):
+    """A 44-digit key."""
+    _size = 44
+
+
 class Key(CryptoDigits):
     """A 16-digit key."""
     _size = 16
@@ -224,7 +229,7 @@ class Secret(CryptoDigits):
 
 
 class Token(CryptoDigits):
-    """A 64-digit secret."""
+    """A variable-length token."""
     _size = None  # depends on JWT data
 
 
