@@ -1,14 +1,5 @@
-# Copyright REFITT Team 2019. All rights reserved.
-#
-# This program is free software: you can redistribute it and/or modify it under the
-# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-# PARTICULAR PURPOSE. See the Apache License for more details.
-#
-# You should have received a copy of the Apache License along with this program.
-# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.
+# SPDX-FileCopyrightText: 2021 REFITT Team
+# SPDX-License-Identifier: Apache-2.0
 
 """Integration tests for /observation endpoints."""
 
@@ -786,6 +777,33 @@ class TestGetType(Endpoint):
         )
 
 
+class TestGetTypes(Endpoint):
+    """Tests for GET /observation/type endpoint."""
+
+    route: str = '/observation/type'
+    method: str = 'get'
+    admin: str = 'superman'
+    user: str = 'tomb_raider'
+
+    def test_invalid_parameter(self) -> None:
+        admin = self.get_client(self.admin)
+        assert self.get(self.route, client_id=admin.id, foo='42') == (
+            RESPONSE_MAP[ParameterInvalid], {
+                'Status': 'Error',
+                'Message': 'Unexpected parameter: foo'
+            }
+        )
+
+    def test_get_all(self) -> None:
+        client = self.get_client(self.user)
+        types = ObservationType.query().all()
+        assert self.get(self.route, client_id=client.id) == (
+            STATUS['OK'], {
+                'Status': 'Success',
+                'Response': {'observation_type': [record.to_json() for record in types]}}
+        )
+
+
 class TestGetAlert(Endpoint):
     """Tests for GET /observation/alert/<id> endpoint."""
 
